## Checklist before merging 
- [ ] Changelog updated in commands/info.changelog() (only empty changelog after merge into master)
- [ ] Completion script updated
- [ ] Config.json changes reflected in source/get_data.validate_config
- [ ] Settings properly updated and validated
- [ ] Man-page updated
- [ ] README updated
